@@ -18,7 +18,9 @@ default_config = {
         'buffet.template_options': {},
         'default_renderer':'json',
         'renderers': ['json'],
-        'render_functions':{'json':tg.render.render_json},
+        'render_functions': {'json': tg.renderers.json.JSONRenderer.render_json},
+        'rendering_engines_options': {'json': {'content_type': 'application/json'}},
+        'rendering_engines_without_vars': set(('json',)),
         'use_legacy_renderers':False,
         'use_sqlalchemy': False,
         'lang': None
