@@ -7,8 +7,10 @@ from crank.util import get_params_with_argspec
 import tg
 import tests
 from json import loads, dumps
+import datetime
 
-from tg.controllers import TGController, DecoratedController
+from tg.controllers import TGController, DecoratedController, abort
+from tg.controllers.util import validation_errors_response
 from tg.decorators import expose, validate, before_render, before_call, Decoration
 from tests.base import (TestWSGIController, data_dir,
     make_app, setup_session_dir, teardown_session_dir)
@@ -260,6 +262,23 @@ class BasicTGController(TGController):
     def validate_callable(self, uid, num):
         return 'HUH'
 
+    @expose()
+    @validate({'uid': validators.Int()},
+              error_handler=abort(412, error_handler=True))
+    def abort_error_handler(self):
+        return 'HUH'
+
+    @expose()
+    @validate({'uid': validators.Int()},
+              error_handler=validation_errors_response)
+    def validate_json_errors(self):
+        return 'HUH'
+
+    @expose()
+    def validate_json_errors_complex_types(self, date):
+        tg.request.validation['values'] = {'date': datetime.datetime.utcnow()}
+        return validation_errors_response()
+
     @expose()
     @before_call(lambda remainder, params: params.setdefault('num', 5))
     def hooked_error_handler(self, uid, num):
@@ -502,4 +521,18 @@ class TestTGController(TestWSGIController):
         # This is done to check that we don't break compatibility
         # with external modules that perform custom validation like tgext.socketio
         resp = self.app.post('/manually_handle_validation')
-        assert resp.text == 'UID: 2', resp
\ No newline at end of file
+        assert resp.text == 'UID: 2', resp
+
+    def test_abort_error_handler(self):
+        resp = self.app.post('/abort_error_handler', {'uid': 'NaN'}, status=412)
+        assert resp.status.startswith('412')
+
+    def test_json_error_handler(self):
+        resp = self.app.post('/validate_json_errors', {'uid': 'NaN'}, status=412)
+        assert resp.json['errors']['uid'] == 'Please enter an integer value'
+
+    def test_json_error_handler_complex_type(self):
+        resp = self.app.post('/validate_json_errors_complex_types', {'date': '2014-01-01'},
+                             status=412)
+        assert resp.json['values']['date'] == '2014-01-01', resp
+
