@@ -18,10 +18,9 @@ from tg.support.converters import asbool, asint, aslist
 from tg.request_local import config as reqlocal_config
 
 import tg
-from tg.configuration.utils import coerce_config
-from tg.util import Bunch, get_partial_dict, DottedFileNameFinder
+from tg.util import Bunch, DottedFileNameFinder
 from tg.configuration import milestones
-from tg.configuration.utils import TGConfigError
+from tg.configuration.utils import TGConfigError, coerce_config, get_partial_dict
 
 from tg.renderers.genshi import GenshiRenderer
 from tg.renderers.json import JSONRenderer
@@ -29,6 +28,7 @@ from tg.renderers.jinja import JinjaRenderer
 from tg.renderers.mako import MakoRenderer
 from tg.renderers.kajiki import KajikiRenderer
 
+
 log = logging.getLogger(__name__)
 
 
@@ -71,7 +71,7 @@ class DispatchingConfigWrapper(DictMixin):
             try:
                 return self.config_proxy.current_conf()[key]
             except KeyError:
-                return get_partial_dict(key, self.config_proxy.current_conf())
+                return get_partial_dict(key, self.config_proxy.current_conf(), Bunch)
 
     def __setattr__(self, key, value):
         self.config_proxy.current_conf()[key] = value
@@ -1153,8 +1153,8 @@ class AppConfig(Bunch):
             app = self.add_core_middleware(app)
 
             if self.auth_backend:
-                # Skipping authentication if explicitly requested. Used by
-                # repoze.who-testutil:
+                # Skipping authentication if explicitly requested.
+                # Used by repoze.who-testutil:
                 skip_authentication = app_conf.get('skip_authentication', False)
                 app = self.add_auth_middleware(app, skip_authentication)
 
@@ -1186,7 +1186,7 @@ class AppConfig(Bunch):
                 app = SeekableRequestBodyMiddleware(app)
 
             if 'PYTHONOPTIMIZE' in os.environ:
-                warnings.warn("Forcing full_stack=False due to PYTHONOPTIMIZE enabled. "+\
+                warnings.warn("Forcing full_stack=False due to PYTHONOPTIMIZE enabled. "
                               "Error Middleware will be disabled", RuntimeWarning, stacklevel=2)
                 full_stack = False
 
