@@ -11,6 +11,7 @@ needed to support these decorators.
 import copy
 import warnings
 import time
+from functools import partial
 from webob.exc import HTTPUnauthorized, HTTPMethodNotAllowed, HTTPMovedPermanently
 from tg.support import NoDefault
 from tg.support.paginate import Page
@@ -18,7 +19,7 @@ from tg.configuration import config
 from tg.configuration.app_config import _DeprecatedControllerWrapper, call_controller
 from tg.controllers.util import abort, redirect
 from tg import tmpl_context, request, response
-from tg.util import partial, Bunch
+from tg.util import Bunch
 from tg.configuration.sqla.balanced_session import force_request_engine
 from tg.flash import flash
 from tg.caching import beaker_cache, cached_property, _cached_call
@@ -594,6 +595,29 @@ class validate(object):
         return func
 
 
+class decode_params(object):
+    """Decorator that enables parsing parameters from request body.
+
+    By default the arguments are parsed in **JSON** format (which is
+    currently the only supported format).
+
+    """
+    def __init__(self, format='json'):
+        if format not in ('json', ):
+            raise ValueError('Currently only JSON format is supported')
+
+        self._format = format
+
+    def run_hook(self, remainder, params):
+        if self._format == 'json' and request.content_type == 'application/json':
+            params.update(request.json_body)
+
+    def __call__(self, func):
+        decoration = Decoration.get_decoration(func)
+        decoration._register_hook('before_validate', self.run_hook)
+        return func
+
+
 class paginate(object):
     """Paginate a given collection.
 
@@ -961,7 +985,7 @@ class cached(object):
 
             def cached_call_controller(controller, remainder, params):
                 if self.key:
-                    key_dict = tg.request.args_params
+                    key_dict = request.args_params
                     if self.key != NoDefault:
                         if isinstance(self.key, (list, tuple)):
                             key_dict = dict((k, key_dict[k]) for k in key_dict)
