@@ -1,4 +1,5 @@
-import hmac, base64, binascii, re
+import hmac, base64, binascii
+import warnings
 from tg.support.objectproxy import TurboGearsObjectProxy
 from tg.support.registry import StackedObjectProxy, DispatchingConfig
 from tg.caching import cached_property
@@ -18,6 +19,7 @@ from webob import Response as WebObResponse
 from webob.request import PATH_SAFE
 from webob.compat import url_quote as webob_url_quote, bytes_ as webob_bytes_
 
+
 class Request(WebObRequest):
     """WebOb Request subclass
 
@@ -57,16 +59,22 @@ class Request(WebObRequest):
     def plain_languages(self):
         return self.languages_best_match()
 
-    @property
+    @cached_property
     def languages(self):
         return self.languages_best_match(self._language)
 
     @property
     def language(self):
+        warnings.warn("request.language is now deprecated, use tg.config['lang'] to"
+                      "read application fallback language.",
+                      DeprecationWarning, stacklevel=2)
         return self._language
 
     @language.setter
     def language(self, value):
+        warnings.warn("Setting request.language is now deprecated, use tg.i18n functions"
+                      "to change the fallback language.",
+                      DeprecationWarning, stacklevel=2)
         self._language = value
 
     @property
@@ -120,6 +128,7 @@ class Request(WebObRequest):
     def _fast_setattr(self, name, value):
         object.__setattr__(self, name, value)
 
+
 class Response(WebObResponse):
     """WebOb Response subclass"""
     content = WebObResponse.body
@@ -146,6 +155,7 @@ class Response(WebObResponse):
 config = DispatchingConfig()
 context = StackedObjectProxy(name="context")
 
+
 class TurboGearsContextMember(TurboGearsObjectProxy):
     """Member of the TurboGears request context.
 
@@ -170,4 +180,5 @@ tmpl_context = TurboGearsContextMember(name="tmpl_context")
 url = TurboGearsContextMember(name="url")
 translator = TurboGearsContextMember(name="translator")
 
-__all__ = ['app_globals', 'request', 'response', 'tmpl_context', 'session', 'cache', 'translator', 'url', 'config']
\ No newline at end of file
+__all__ = ['app_globals', 'request', 'response', 'tmpl_context', 'session',
+           'cache', 'translator', 'url', 'config']
\ No newline at end of file
