@@ -1,36 +1,11 @@
 """Utilities"""
 from pkg_resources import resource_filename
 import warnings
-from tg.request_local import request
-from functools import partial, update_wrapper
+from functools import update_wrapper
+from tg.configuration.utils import get_partial_dict
 
 
-class DottedFileLocatorError(Exception):pass
-
-
-def get_partial_dict(prefix, dictionary):
-    """Given a dictionary and a prefix, return a Bunch, with just items
-    that start with prefix
-
-    The returned dictionary will have 'prefix.' stripped so:
-
-    get_partial_dict('prefix', {'prefix.xyz':1, 'prefix.zyx':2, 'xy':3})
-
-    would return:
-
-    {'xyz':1,'zyx':2}
-    """
-
-    match = prefix + "."
-    n = len(match)
-
-    new_dict = Bunch([(key[n:], dictionary[key])
-                       for key in dictionary.keys()
-                       if key.startswith(match)])
-    if new_dict:
-        return new_dict
-    else:
-        raise AttributeError
+class DottedFileLocatorError(Exception): pass
 
 
 class Bunch(dict):
@@ -43,7 +18,7 @@ class Bunch(dict):
         try:
             return self[name]
         except KeyError:
-            return get_partial_dict(name, self)
+            return get_partial_dict(name, self, Bunch)
 
     __setattr__ = dict.__setitem__
 
@@ -112,8 +87,23 @@ class DottedFileNameFinder(object):
 
             return result
 
+    @classmethod
+    def lookup(cls, name, extension='.html'):
+        """Convenience method that permits to quickly get a file by dotted notation.
+
+        Creates a :class:`.DottedFileNameFinder` and uses it to lookup the given file
+        using dotted notation. As :class:`.DottedFileNameFinder` provides a lookup
+        cache, using this method actually disables the cache as a new finder is created
+        each time, for this reason if you have recurring lookups it's better to actually
+        create a dotted filename finder and reuse it.
+
+        """
+        finder = cls()
+        return finder.get_dotted_filename(name, extension)
+
 
 def no_warn(f, *args, **kwargs):
+    """Decorator that suppresses warnings inside the decorated function"""
     def _f(*args, **kwargs):
         warnings.simplefilter("ignore")
         f(*args, **kwargs)
@@ -122,8 +112,12 @@ def no_warn(f, *args, **kwargs):
 
 
 class LazyString(object):
-    """Has a number of lazily evaluated functions replicating a
-    string. Just override the eval() method to produce the actual value.
+    """Behaves like a string, but no instance is created until the string is actually used.
+
+    Takes a function which should be a string factory and a set of arguments to pass
+    to the factory. Whenever the string is accessed or manipulated the factory is called
+    to create the actual string. This is used mostly by lazy internationalization.
+
     """
     def __init__(self, func, *args, **kwargs):
         self.func = func
@@ -147,50 +141,15 @@ class LazyString(object):
 
 
 def lazify(func):
-    """Decorator to return a lazy-evaluated version of the original"""
+    """Decorator to return a lazy-evaluated version of the original
+
+    Applying decorator to a function it will create a :class:`.LazyString`
+    with the decorated function as factory.
+
+    """
     def newfunc(*args, **kwargs):
         return LazyString(func, *args, **kwargs)
     newfunc.__name__ = 'lazy_%s' % func.__name__
     newfunc.__doc__ = 'Lazy-evaluated version of the %s function\n\n%s' % \
         (func.__name__, func.__doc__)
     return newfunc
-
-
-class ContextObj(object):
-    def __repr__(self):
-        attrs = sorted((name, value)
-                       for name, value in self.__dict__.items()
-                       if not name.startswith('_'))
-        parts = []
-        for name, value in attrs:
-            value_repr = repr(value)
-            if len(value_repr) > 70:
-                value_repr = value_repr[:60] + '...' + value_repr[-5:]
-            parts.append(' %s=%s' % (name, value_repr))
-        return '<%s.%s at %s%s>' % (
-            self.__class__.__module__,
-            self.__class__.__name__,
-            hex(id(self)),
-            ','.join(parts))
-
-    def __getattr__(self, item):
-        if item in ('form_values', 'form_errors'):
-            warnings.warn('tmpl_context.form_values and tmpl_context.form_errors got deprecated '
-                          'use request.validation instead', DeprecationWarning)
-            return request.validation[item[5:]]
-        elif item == 'controller_url':
-            warnings.warn('tmpl_context.controller_url got deprecated, '
-                          'use request.controller_url instead', DeprecationWarning)
-            return request.controller_url
-
-        raise AttributeError()
-
-
-class AttribSafeContextObj(ContextObj):
-    """The :term:`tmpl_context` object, with lax attribute access (
-    returns '' when the attribute does not exist)"""
-    def __getattr__(self, name):
-        try:
-            return ContextObj.__getattr__(self, name)
-        except AttributeError:
-            return ''
